
'''
This file is automatically generated by setup.py, So don't edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.12.4',
    'branch_nick': '(detached',
    'revision_id': '7f05f7a57d236c744905658d9155bd59b142fc65',
    'revno': 5244
}
